import React, { useMemo } from 'react';
import { createColumnHelper, flexRender, getCoreRowModel, useReactTable } from '@tanstack/react-table';
import './index.css';
var ResourceTable = function(param) {
    var data = param.data, headings = param.headings;
    // Create columns based on headings
    var columnHelper = createColumnHelper();
    var columns = useMemo(function() {
        return headings.map(function(heading) {
            return columnHelper.accessor(heading.key, {
                header: function() {
                    return heading.text;
                },
                cell: function(info) {
                    var value = info.getValue();
                    if (Array.isArray(value)) {
                        return /*#__PURE__*/ React.createElement("div", {
                            style: {
                                display: 'flex',
                                flexDirection: 'column',
                                gap: 4,
                                wordBreak: 'break-all'
                            }
                        }, value.map(function(item, index) {
                            return /*#__PURE__*/ React.createElement("div", {
                                key: index
                            }, item);
                        }));
                    } else if (Object.prototype.toString.call(value) === '[object Object]') {
                        return /*#__PURE__*/ React.createElement("pre", {
                            style: {
                                whiteSpace: 'pre-wrap',
                                wordBreak: 'break-all'
                            }
                        }, JSON.stringify(value, null, 2));
                    }
                    return value;
                }
            });
        });
    }, [
        headings,
        columnHelper
    ]);
    var table = useReactTable({
        data: data,
        columns: columns,
        getCoreRowModel: getCoreRowModel()
    });
    return /*#__PURE__*/ React.createElement("div", {
        className: "resource-table-container"
    }, /*#__PURE__*/ React.createElement("table", {
        className: "resource-table"
    }, /*#__PURE__*/ React.createElement("thead", null, table.getHeaderGroups().map(function(headerGroup) {
        return /*#__PURE__*/ React.createElement("tr", {
            key: headerGroup.id
        }, headerGroup.headers.map(function(header) {
            return /*#__PURE__*/ React.createElement("th", {
                key: header.id,
                style: {
                    width: header.id === 'url' ? '40%' : 'auto'
                }
            }, header.isPlaceholder ? null : flexRender(header.column.columnDef.header, header.getContext()));
        }));
    })), /*#__PURE__*/ React.createElement("tbody", null, table.getRowModel().rows.map(function(row) {
        return /*#__PURE__*/ React.createElement("tr", {
            key: row.id
        }, row.getVisibleCells().map(function(cell) {
            return /*#__PURE__*/ React.createElement("td", {
                key: cell.id
            }, flexRender(cell.column.columnDef.cell, cell.getContext()));
        }));
    }))));
};
export default ResourceTable;

//# sourceMappingURL=index.js.map