import I18n from '../i18n';
export var getColorWithScore = function(level) {
    var colors = {
        A: '#2ac88f',
        B: '#1677ff',
        C: '#f6a300'
    };
    return colors[level];
};
export var calcCategorieMap = function(categories, tasks) {
    var categoriesMap = {
        performance: {
            score: 0,
            level: '',
            passedTasks: [],
            failedTasks: [],
            uncheckedTasks: []
        },
        experience: {
            score: 0,
            level: '',
            passedTasks: [],
            failedTasks: [],
            uncheckedTasks: []
        },
        'best-practice': {
            score: 0,
            level: '',
            passedTasks: [],
            failedTasks: [],
            uncheckedTasks: []
        }
    };
    Object.keys(tasks).forEach(function(key) {
        // @ts-ignore
        var task = tasks[key];
        switch(key){
            case 'script_execution_time':
            case 'fmp_time':
            case 'render_time':
            case 'lower_average_frame_rate':
            case 'setData_calls':
            case 'setData_size':
            case 'tyml_nodes':
            case 'network_request_time':
            case 'network_concurrent_requests':
            case 'image_concurrent_requests':
            case 'image_size_check':
            case 'mini_program_package_size':
            case 'ttt_concurrent_calls':
            case 'app_theme_variables':
            case 'dark_mode_support':
            case 'multi_language_usage':
            case 'clickable_element_response_area':
            case 'safe_area_compatibility':
            case 'js_error_logs':
            case 'https_compliance':
            case 'package_image_check':
            case 'cross_region_access':
            case 'dp_data_change':
                task.key = key;
                task.passedTitle = I18n.t("".concat(key, "_passedTitle"));
                task.failedTitle = I18n.t("".concat(key, "_failedTitle"));
                task.title = I18n.t("".concat(key));
                task.desc = I18n.t("".concat(key, "_desc"));
                task.headings = task.details.length > 0 ? Object.keys(task.details[0]).map(function(headingKey) {
                    if (I18n.t("".concat(key, "_headings_").concat(headingKey)) === "".concat(key, "_headings_").concat(headingKey)) {
                        return undefined;
                    }
                    return {
                        key: headingKey,
                        text: I18n.t("".concat(key, "_headings_").concat(headingKey))
                    };
                }).filter(Boolean) : [];
                break;
            default:
                break;
        }
    });
    categories.forEach(function(category) {
        var categoryTasks = [];
        var passedTasks = [];
        var failedTasks = [];
        var uncheckedTasks = [];
        switch(category.type){
            case 'performance':
                categoriesMap.performance.level = category.level;
                categoriesMap.performance.score = category.score;
                categoryTasks = category.task_keys.map(function(key) {
                    return tasks[key];
                });
                passedTasks = categoryTasks.filter(function(item) {
                    return item.status === 'passed';
                });
                failedTasks = categoryTasks.filter(function(item) {
                    return item.status === 'failed';
                });
                uncheckedTasks = categoryTasks.filter(function(item) {
                    return item.status === 'unchecked';
                });
                // @ts-ignore
                categoriesMap.performance.passedTasks = passedTasks;
                // @ts-ignore
                categoriesMap.performance.failedTasks = failedTasks;
                // @ts-ignore
                categoriesMap.performance.uncheckedTasks = uncheckedTasks;
                break;
            case 'experience':
                categoriesMap.experience.level = category.level;
                categoriesMap.experience.score = category.score;
                categoryTasks = category.task_keys.map(function(key) {
                    return tasks[key];
                });
                passedTasks = categoryTasks.filter(function(item) {
                    return item.status === 'passed';
                });
                failedTasks = categoryTasks.filter(function(item) {
                    return item.status === 'failed';
                });
                uncheckedTasks = categoryTasks.filter(function(item) {
                    return item.status === 'unchecked';
                });
                // @ts-ignore
                categoriesMap.experience.passedTasks = passedTasks;
                // @ts-ignore
                categoriesMap.experience.failedTasks = failedTasks;
                // @ts-ignore
                categoriesMap.experience.uncheckedTasks = uncheckedTasks;
                break;
            case 'best-practice':
                categoriesMap['best-practice'].level = category.level;
                categoriesMap['best-practice'].score = category.score;
                categoryTasks = category.task_keys.map(function(key) {
                    return tasks[key];
                });
                passedTasks = categoryTasks.filter(function(item) {
                    return item.status === 'passed';
                });
                failedTasks = categoryTasks.filter(function(item) {
                    return item.status === 'failed';
                });
                uncheckedTasks = categoryTasks.filter(function(item) {
                    return item.status === 'unchecked';
                });
                // @ts-ignore
                categoriesMap['best-practice'].passedTasks = passedTasks;
                // @ts-ignore
                categoriesMap['best-practice'].failedTasks = failedTasks;
                // @ts-ignore
                categoriesMap['best-practice'].uncheckedTasks = uncheckedTasks;
                break;
            default:
                break;
        }
    });
    return categoriesMap;
};

//# sourceMappingURL=index.js.map